@@ -12,6 +12,7 @@ use File::Spec;
 sub opt_spec {
     return (
         ['state=s',    "CSV of states to show."],
+        ['all',        "Don't filter by profile."],
     );
 }
 
@@ -27,13 +28,15 @@ sub description {
 sub execute {
     my($cmd,$opt,$args) = @_;
 
-    my %SHOW = map { $_ => 1 } exists $opt->{state} ? split /,|\s+/, $opt->{state} : ();
+    my %SHOW = exists $opt->{state} ? map { $_ => 1 } split /,|\s+/, $opt->{state} : ();
     my $audit = gcr_repo();
+    my $profile = gcr_profile();
     gcr_reset();
 
     my @list = grep /\.patch$/, $audit->run('ls-files');
     if( @list ) {
-        my %info = ();
+        my %states = ();
+        my %profiles = ();
         my @commits = map { $_=gcr_commit_info( basename $_ ) } @list;
         output({color=>'cyan'}, sprintf "-[ Commits in the Audit %s:: %s ]-",
             scalar(keys %SHOW) ? '(' . join(',', sort keys %SHOW) . ') ' : '',
@@ -49,24 +52,40 @@ sub execute {
         # Assemble Commits
         foreach my $commit ( sort { $a->{date} cmp $b->{date} } @commits ) {
             $commit->{state} = 'resigned' unless gcr_not_resigned($commit->{base});
-            $info{$commit->{state}} ||= 0;
-            $info{$commit->{state}}++;
+            $states{$commit->{state}} ||= 0;
+            $states{$commit->{state}}++;
+            $profiles{$commit->{profile}} ||= 0;
+            $profiles{$commit->{profile}}++;
+            # State filter
             next if keys %SHOW && !exists $SHOW{$commit->{state}};
+            # Profile filter
+            next unless (exists $opt->{all} && $opt->{all}) || $commit->{profile} eq $profile;
+
             my $color = gcr_state_color($commit->{state});
             output({indent=>1,color=>$color}, join("\t",
-                    $commit->{state}, $commit->{date}, $commit->{sha1}, $commit->{author},
+                    $commit->{profile},
+                    $commit->{state},
+                    $commit->{date},
+                    $commit->{sha1},
+                    $commit->{author},
                     exists $comments{$commit->{sha1}} ? "(comments:$comments{$commit->{sha1}})" : "",
                 )
             );
+            debug_var($commit);
         }
-        output({color=>'cyan'}, sprintf "-[ Status %s from %s ]-",
-            join(', ', map { "$_:$info{$_}" } sort keys %info),
-            gcr_origin('source')
+        output({color=>'cyan'}, sprintf "-[ Status  : %s ]-",
+            join(', ', map { "$_:$states{$_}" } sort keys %states)
         );
+        output({color=>'cyan'}, sprintf "-[ Profile : %s ]-",
+            join(', ', map { "$_:$profiles{$_}" } sort keys %profiles)
+        );
+        output({color=>'cyan'}, sprintf "-[ Source  : %s ]-", gcr_origin('source') );
     }
     else {
-        output({color=>'green'}, "No commits flagged with concerns!");
+        output({color=>'green'}, "No commits matching criteria!");
     }
+    my $config = gcr_config();
+    debug_var($config);
 }
 
 1;
@@ -83,7 +102,7 @@ Git::Code::Review::Command::list - Quick overview of the Audit Directory
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 AUTHOR
 
